Fix mask length bug in print_affinitylist.

The incoming length argument is in terms of bytes not
longs.

As a result, a buffer overrun occurs and either four or
eight times more mask data than is actually available
is displayed.

This patch is against strace-4.11.

Signed-off-by: Joe Korty <joe.korty@ccur.com>

Index: b/affinity.c
===================================================================
--- a/affinity.c
+++ b/affinity.c
@@ -32,12 +32,12 @@ static void
 print_affinitylist(struct tcb *tcp, const unsigned long addr, const unsigned int len)
 {
 	unsigned long w;
-	const unsigned int size = len * sizeof(w);
+	const unsigned int size = len;
 	const unsigned long end = addr + size;
 	unsigned long cur, abbrev_end;
 
 	if (!verbose(tcp) || (exiting(tcp) && syserror(tcp)) ||
-	    !addr || !len || size / sizeof(w) != len || end < addr) {
+	    !addr || !len || len & (sizeof(w) - 1) || end < addr) {
 		printaddr(addr);
 		return;
 	}
